from typing import Any

def hexlify(*args, **kwargs) -> Any: ...

class MQTTClient:
    def ping(self, *args, **kwargs) -> Any: ...
    def publish(self, *args, **kwargs) -> Any: ...
    def wait_msg(self, *args, **kwargs) -> Any: ...
    def subscribe(self, *args, **kwargs) -> Any: ...
    def check_msg(self, *args, **kwargs) -> Any: ...
    def set_last_will(self, *args, **kwargs) -> Any: ...
    def connect(self, *args, **kwargs) -> Any: ...
    def disconnect(self, *args, **kwargs) -> Any: ...
    def set_callback(self, *args, **kwargs) -> Any: ...
    def __init__(self, *argv, **kwargs) -> None: ...

class MQTTException(Exception): ...



from typing import Any

def request(*args, **kwargs) -> Any: ...
def head(*args, **kwargs) -> Any: ...
def post(*args, **kwargs) -> Any: ...
def patch(*args, **kwargs) -> Any: ...
def delete(*args, **kwargs) -> Any: ...
def put(*args, **kwargs) -> Any: ...
def get(*args, **kwargs) -> Any: ...

class Response:
    def json(self, *args, **kwargs) -> Any: ...
    def close(self, *args, **kwargs) -> Any: ...
    content: Any
    text: Any
    def __init__(self, *argv, **kwargs) -> None: ...



"""
JSON encoding and decoding.

MicroPython module: https://docs.micropython.org/en/v1.19.1/library/json.html

CPython module: :mod:`python:json` https://docs.python.org/3/library/json.html .

This modules allows to convert between Python objects and the JSON
data format.
"""
from typing import Any
from _typeshed import Incomplete

def loads(str) -> Incomplete:
    """
    Parse the JSON *str* and return an object.  Raises :exc:`ValueError` if the
    string is not correctly formed.
    """
    ...

def load(stream) -> Incomplete:
    """
    Parse the given *stream*, interpreting it as a JSON string and
    deserialising the data to a Python object.  The resulting object is
    returned.

    Parsing continues until end-of-file is encountered.
    A :exc:`ValueError` is raised if the data in *stream* is not correctly formed.
    """
    ...

def dumps(obj, separators=None) -> str:
    """
    Return *obj* represented as a JSON string.

    The arguments have the same meaning as in `dump`.
    """
    ...

def dump(obj, stream, separators=None) -> Incomplete:
    """
    Serialise *obj* to a JSON string, writing it to the given *stream*.

    If specified, separators should be an ``(item_separator, key_separator)``
    tuple. The default is ``(', ', ': ')``. To get the most compact JSON
    representation, you should specify ``(',', ':')`` to eliminate whitespace.
    """
    ...



from typing import Any

class MQTTClient:
    DEBUG: bool
    DELAY: int
    def ping(self, *args, **kwargs) -> Any: ...
    def check_msg(self, *args, **kwargs) -> Any: ...
    def delay(self, *args, **kwargs) -> Any: ...
    def subscribe(self, *args, **kwargs) -> Any: ...
    def disconnect(self, *args, **kwargs) -> Any: ...
    def connect(self, *args, **kwargs) -> Any: ...
    def set_last_will(self, *args, **kwargs) -> Any: ...
    def log(self, *args, **kwargs) -> Any: ...
    def set_callback(self, *args, **kwargs) -> Any: ...
    reconnect: Any
    wait_msg: Any
    publish: Any
    def __init__(self, *argv, **kwargs) -> None: ...
